Struct DeviceListener

pub struct DeviceListener { /* private fields */ }
An owned listener for device events.

This is created by DeviceListenerLocalBuilder and will receive events as long as it is alive. When this gets dropped, the listener gets unregistered and no events will be received by it.